Name: ovs-config
Version: 3.4.1
Release: 5%{?dist}.2.3
Summary: Configurations for OVM server.
License: GPL
Group: Applications/System
URL: http://www.oracle.com/
Source: %{name}-%{version}.tar.gz
Patch1: rev259.patch
Patch2: rev267.patch
Patch3: rev274.patch
Patch4: rev303.patch
Patch5: rev310.patch
Patch6: rev325.patch
Patch7: rev333.patch
Patch8: revert_max_queues_1.patch
# End Oracle Patches

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildArch: noarch
Requires: module-init-tools
Requires: ntp
Requires: iptables
Requires: iptables-ipv6
Requires: iscsi-initiator-utils
Requires: setup
Requires: ed
Requires: lvm2
Requires: initscripts
Requires: libvirt-daemon

%description
Configurations for OVM server.

%prep
%setup -q
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p0
%patch5 -p0
%patch6 -p0
%patch7 -p0
%patch8 -p0

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=${RPM_BUILD_ROOT} install

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ $1 -eq 1 ]; then  # For install
    # Remove default ntp servers. (Oracle-Bug: 17628996)
    sed -i '/^server .\.rhel\.pool\.ntp\.org/s//#&/' /etc/ntp.conf

    # Adjust iSCSI session timeout (Oracle-Bug: 14175849)
    sed -i '/^node.session.timeo.replacement_timeout/s/120/10/' /etc/iscsi/iscsid.conf

    # Disable iptables
    chkconfig iptables off
    chkconfig ip6tables off

    # Make sure we have the /etc/motd warning message
    echo -e "Warning: making manual modifications in the management domain\nmight cause inconsistencies between Oracle VM Manager and the server.\n" >/etc/motd

    # Make sure hvc0 and ttyS0 are in /etc/securetty
    for t in hvc0 ttyS0; do
        fgrep -qx $t /etc/securetty || echo $t >>/etc/securetty
    done

    # Disable lvm scanning (Oracle-Bug: 17999985 Oracle-Bug: 24583291).
    if ! grep -E -q "^[[:space:]]*global_filter" /etc/lvm/lvm.conf >/dev/null; then
        sed -i 's/# global_filter = \[ "a|\.\*\/|" \]/global_filter = [ "r|.*\/|" ]/g' /etc/lvm/lvm.conf
        rm -f /etc/lvm/cache/.cache
    fi

    # Show status console (Oracle-Bug: 17614147).
    sed -ri '/^ACTIVE_CONSOLES=/s|="?/dev/tty\[1-6\]"?|=/dev/tty[2-6]|' /etc/sysconfig/init

    # Disable bridge multicast_snooping (Oracle-Bug: 16746299).
    for f in /etc/sysconfig/network-scripts/ifcfg-*; do
        . $f
        if [ "$TYPE" == "Bridge" -a -z "$BRIDGING_OPTS" ]; then
            echo 'BRIDGING_OPTS="multicast_snooping=0"' >> $f
        fi
    done

    # Fix reboot after upgrading from 3.1.x/3.2.x.
    if ! grep -E -q "^[[:space:]]*l6:6:wait:/etc/rc.d/rc 6" /etc/inittab >/dev/null; then
        echo "l6:6:wait:/etc/rc.d/rc 6" >>/etc/inittab
    fi

elif [ $1 -eq 2 ]; then # For upgrade

    # anaconda created blacklisted.wwids in OVS3.3
    if [ -f /etc/blacklisted.wwids ]; then
        sed -i 's/^wwid/        wwid/' /etc/blacklisted.wwids
        sed -i -e '/%include/ r /etc/blacklisted.wwids' -e '/%include/d' /etc/multipath.conf
        sed -i -e '/#OVSBLACKLIST/ r /etc/blacklisted.wwids' -e '/#OVSBLACKLIST/d' /etc/multipath.conf
        rm /etc/blacklisted.wwids
    fi

    # Convert deprecated ETHTOOL_OFFLOAD_OPT to OL6 ETHTOOL_OPTS
    for dev_cfg in $(grep -l "DEVICE" /etc/sysconfig/network-scripts/ifcfg-*) ;
    do
        OLD_OPTS=`cat ${dev_cfg} | grep "ETHTOOL_OFFLOAD_OPT" || : `
        if [ -n "${OLD_OPTS}" ]; then
            device="$(echo ${dev_cfg##*/} | awk -F- '{ print $2 }')"
            sed -i '/ETHTOOL_OFFLOAD_OPT/d' ${dev_cfg}
            lro=`echo ${OLD_OPTS} | grep "lro" || : `
            gro=`echo ${OLD_OPTS} | grep "gro" || : `
            if [ -n "${lro}" ] && [ -n "${gro}" ]; then
                echo "ETHTOOL_OPTS=\"-K $device lro off gro off\"" >> ${dev_cfg}
            elif [ -n "${lro}" ]; then
                echo "ETHTOOL_OPTS=\"-K $device lro off\"" >> ${dev_cfg}
            elif [ -n "${gro}" ]; then
                echo "ETHTOOL_OPTS=\"-K $device gro off\"" >> ${dev_cfg}
            fi
        fi
    done
fi

# Disable libvirt
chkconfig --del libvirt-guests
chkconfig --del libvirtd

%files
%defattr(-,root,root)
%{_sysconfdir}/modprobe.d/ovs.conf
%{_sysconfdir}/sysctl.d/ovs.conf
%{_sysconfdir}/init/tty1.conf
%{_sysconfdir}/mdadm.conf
%config(noreplace) %{_sysconfdir}/multipath.conf
%{_sysconfdir}/udev/rules.d/61-persistent-storage-nvme.rules
%{_sbindir}/*

%changelog
* Tue Sep 13 2016 Firas Azar <firas.azar@oracle.com> - 3.4.1-5.el6.2.3 
- Signed-off by: Firas Azar <firas.azar@oracle.com>
  Signed-off by: Adnan Misherfi <adnan.misherfi@oracle.com> [bug 24464484]  

* Tue Sep 13 2016 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.4.1-5.el6.2.2 
- Fix lvm2 global_filter parsing
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com>
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com> [bug 24583291]  

* Thu Sep 08 2016 Firas Azar <firas.azar@oracle.com> - 3.4.1-5.el6.2.1 
- Signed-off-by: Firas Azar <firas.azar@oracle.com>
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com>
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com>
  Disable multi-queue in XEN blkback by setting xen_blkback.max_queues to 1. [bug 24464484]  

* Thu Jul 21 2016 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.4.1-5.el6.2 
- Add comments for xen_netback max_queues
  If dom0 has less than 8 CPUs, xen_netback max_queues in
  /etc/modproble.d/ovs.conf should match dom0 CPU number
  for best performance.
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com>
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com>
  Signed-off-by: Konrad Wilk <konrad.wilk@oracle.com> [bug 24329130] [bug 22545396]  

* Tue Jul 19 2016 Ke-Chiang Chen <ke-chiang.chen@oracle.com> - 3.4.1-5.el6.1 
- To add udev 61-persistent-storage-nvme.rules
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com>
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com> [bug 22163111]  

* Fri Jan 29 2016 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.4.1-5 
- Prevent owned OVM Server node to be converted to OpenStack Compute node
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com>
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com> 

* Wed Jan 27 2016 Natalya Naumova <natalya.naumova@oracle.com> - 3.4.1-4
- changed specfile for bz 22610829 (carson.hovey@oracle.com) [bug 22610829]
 
* Wed Jan 27 2016 Carson Hovey <carson.hovey@oracle.com> - 3.4.1-3 
- libvirtd should be disabled for both install and upgrade code paths
  Bug-fixed-by: Carson Hovey <carson.hovey@oracle.com>
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com> [bug 22610829] [bug After] [bug 3.3] [bug upgrade]  

* Fri Jan 22 2016 Kevin Lyons <kevin.x.lyons@oracle.com> - 3.4.1-2
- Add TCP tuning to the server to improve 10G network performance
  (adnan.misherfi@oracle.com)

* Thu Jan 21 2016 Livy Ge <livy.ge@oracle.com> - 3.4.1-1
- add ovm2openstack [bug 22581402] (zhigang.x.wang)

* Thu Jan 21 2016 Srinivas Maturi <srinivas.maturi@oracle.com> - 3.3.1-28 
- add ovm2openstack,22581402 

* Thu Jan 21 2016 Srinivas Maturi <srinivas.maturi@oracle.com> - 3.3.1-27 
- add ovm2openstack,22581402 

* Tue Jan 19 2016 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-26 
- Disable libvirtd by default.
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com>
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com> [bug 22264393]  

* Sun Jan 17 2016 Livy Ge <livy.ge@oracle.com> - 3.3.1-25
- add libvirt-daemon runtime requirement and disable libvirtd [bug 22264393]

* Fri Jan 15 2016 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-24 
- Limit Xen netback max queue to 8.
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com>
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com>
  Signed-off-by: Annie Li <annie.li@oracle.com> [bug 22545396]  

* Thu Sep 17 2015 Ke-Chiang Chen <ke-chiang.chen@oracle.com> - 3.3.1-23 
- Added product SUN ZFS Storage 7330
  Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com>
  Signed-off-by: Cathy Avery <cathy.avery@oracle.com> [bug 21298715]  

* Mon May 04 2015 Adnan Misherfi <adnan.misherfi@oracle.com> - 3.3.1-22 
- Update specfile to convert deprecated ETHTOOL_OFFLOAD_OPT to OL6 ETHTOOL_OPTS [bug 20526269]

* Fri May 01 2015 Adnan Misherfi <adnan.misherfi@oracle.com> - 3.3.1-21 
- While upgrading an older OVM (OL5) server to a newer one (OL6) Convert deprecated ETHTOOL_OFFLOAD_OPT to OL6 ETHTOOL_OPTS in ifcfg files. [bug 20526269]  

* Wed Jan 21 2015 Adnan Misherfi <adnan.misherfi@oracle.com> - 3.3.1-20 
- Remove "options bnx2x disable_tpa=1" from /etc/modprobe.d/ovs.conf it is no longer needed. [bug 20391337]  

* Mon Sep 08 2014 Ke-Chiang Chen <ke-chiang.chen@oracle.com> - 3.3.1-19 
- Signed-off-by: Adnan Misherfi <adnan.misherfi@oracle.com>
  Signed-off-by: Cathy Avery <cathy.avery@oracle.com>
  Signed-off-by: Zhigang Wang <zhigang.x.wang@oracle.com> [bug 17994957]  

* Mon Sep 08 2014 Ke-Chiang Chen <ke-chiang.chen@oracle.com> - 3.3.1-18
- merge device-mapper-multipath [bug 17994957]

* Wed Mar 19 2014 Cathy Avery <cathy.avery@oracle.com> - 3.3.1-17 
- Added mdadm.conf file that will prevent mdadm on the server from grabing mdraid disks intended for the vms. [bug 18366957]  

* Tue Feb 11 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-16 
- reserve customized NTP servers 

* Mon Feb 10 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-15
- reserve customized NTP servers [bug 18224809]

* Mon Feb 10 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-14 
- fix regular expression: make the space optional 

* Mon Feb 03 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-13 
- remove smartmon hack [bug 18174983] 

* Mon Feb 03 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-12
- remove smartmon hack [bug 18174983] 

* Thu Jan 30 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-11 
- fix serial console cannot login issue 

* Wed Jan 29 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-10
- fix serial console [bug 18155737]

* Wed Jan 29 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-9 
- fix configuration file mode 

* Wed Jan 29 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-8  
- delete unused empty file ovm.conf

* Tue Jan 28 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-7 
- Add initscripts as required, and
  show status console,
  disable bridge multicast_snooping,
  fix reboot after upgrading from 3.1.x/3.2.x [bug 18148102]  

* Mon Jan 27 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-6
- Add lvm2 and ed as required, and
  disable lvm scanning [bug 18140934]

* Tue Jan 21 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-5
- Add smartmontools as required, and
  disable smartmontools email notification [bug 18110889]

* Tue Jan 21 2014 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-4
- Add setup as required, and
  make sure /etc/motd warning message, and hvc0 and ttyS0 are 
  in /etc/securetty [bug 18110877]

* Thu Dec 19 2013 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-3
- Add iscsi-initiator-utils as required, and 
  adjust iSCSI session timeout [bug 18071568]

* Thu Dec 19 2013 Zhigang Wang <zhigang.x.wang@oracle.com> - 3.3.1-2
- Add iptables and iptables-ipv6 as required, and
  disable iptables and ip6tables services [bug 18071276]

* Thu Dec 19 2013 John Haxby <john.haxby@oracle.com> - 3.3.1-1
- Initial version.
